<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR" sourcelanguage="en_US">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Downloader Básico</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Obter lista</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Insira a URL:</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Formatar código</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extensão</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Nome da Engine:</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Colar conteúdo da área de transferência</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Recentimente utilizados</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Definir opções de Download</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Downloader em lote</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Thumbnail</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>Url para download</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Colar URL da área de transferência</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Monitorar Área De Transferência Para Url</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Adicionar Url À Lista</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Definir</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Playlist Downloader</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Opções De Download:</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Tempo de ínicio do intervalo(HH:MM:SS):</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Tempo final do intervalo(HH:MM:SS):</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Capítulos(Separados por vírgulas):</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Dividido por capítulos</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>Insira o URL da Playlist:</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Limpar Arquivo Interno</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Usar Arquivo Interno</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Biblioteca</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Para cima</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Abrir Pasta</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Opções Gerais</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Mostrar Ícone Da Bandeja</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Salvar Automaticamente Lista De Mídia Não Baixada</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>Ocultar downloads automaticamente quando concluídos</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Redefinir Opção Para a Padrão</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Definir Padrões</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Opções Predefinidas</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Download Path</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Selecione o Idioma</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>Usar configuração de proxy especificada manualmente</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>Obter configuração de proxy do ambiente</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>Sem proxy</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Opções padrão da Engine</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Tamanho do arquivo</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Obter Opções De Lista:</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Assinaturas</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Nome da UI</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Ativar Aba Biblioteca</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>Máximo de downloads simultâneos</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Codificação De Texto</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>Mostrar informações da versão e atualizações de download automático</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>Mostrar informações da versão e informações da versão mais recente</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>Mostrar apenas informações da versão</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>Não fazer nada</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>Ações na inicialização</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Site</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Nome da Engine</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Default</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Opções Para Adicionar</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Gerenciador De Url</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Opções De Download</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Defina qual Url deve ser gerenciada por qual Engine</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Filtrar Url</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>Configurações de proxy</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>Usar configuração de proxy do sistema</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>Configuração de proxy especificada manualmente
Exemplo 1: 192.168.93.89:8080
Exemplo 2: ${gateway}:8080</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation>Reproduzir mídia baixada</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation>Insira a URL da lista de reprodução. Para adicionar várias listas de reprodução, separe-as com um espaço ou uma nova linha</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Renomear arquivo para o texto abaixo</translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation>Um botão para abrir uma pasta para ser usada como uma pasta de download</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation>Um botão para abrir uma pasta onde os arquivos de configuração do tema são armazenados</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation>Um botão para abrir uma pasta onde os binários da extensão são armazenados</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation>Tem certeza de que deseja redefinir essas opções para os padrões?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>%1 Opções predefinidas</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Arquivo com extensão &quot;.txt&quot; irá salvar apenas URLs</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>Ocultar linha</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>Mostrar todas as linhas ocultas</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>Falha ao iniciar o executável %1</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copy Url</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>Abrir URL com %1</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>Copiar URL %1</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Salvar lista em um arquivo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Respostas para</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Salvar legenda em um arquivo</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Nome da Engine:</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Obter lista a partir do arquivo</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Opções predefinidas</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Abrir pasta de Download</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>Página do Projeto</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Email</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Versão do Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Este programa é software livre, você pode redistribuí-lo e / ou modificá-lo sob os termos da Licença Pública Geral GNU conforme publicada pela Free Software Foundation; seja a versão 2 da licença, ou (a seu critério) qualquer versão posterior.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Este programa é distribuído na esperança de que seja útil,mas sem qualquer garantia; sem sequer a garantia implícita de comerciabilidade ou adequação a um determinado fim. Veja a Licença Pública Geral GNU para mais detalhes.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>Polonês (Polónia)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Inglês (EUA)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Espanhol (Espanha)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>Chinês (China)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>Turco (Turquia)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>Russo (Russo)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>Japonês (Japão)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>Francês (França)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Italiano (Itália)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>Sueco (Suécia)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Alemão (Alemanha)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Português (Brasil)</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>Holandês (Holanda)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Erro, o executável para o backend &quot;%1&quot; não pôde ser encontrado</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>A Engine &quot;%1&quot; requer pelo menos a versão &quot;%2&quot; do Media Downloader</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Para desativar essas verificações, faça o seguinte:-</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>Vá para a guia &quot;Configurar&quot;.</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>Vá para a subguia &quot;Opções gerais&quot;.</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. Clique no menu &quot;Ações na inicialização&quot;.</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. Selecione &quot;Não fazer nada&quot;.</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>Executando no modo portátil</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>Executando no modo de instalação</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>Caminho para download: %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>Caminho de dados do aplicativo: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>Configurando o endereço do servidor proxy de %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>Desconfigurando o endereço do servidor proxy</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Erro, falha ao analisar o arquivo de configuração &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Falha ao carregar um plugin</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Falha ao encontrar o executável &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Falha ao encontrar o executável python3 para o backend &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>Formato solicitado não está disponível</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Ocorreu um erro de rede</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>URL inválida inserida</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>URL não é suportado</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Download cancelado</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Código de erro</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>Falha no download, falha ao iniciar o mecanismo</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Falha no Download,Engine travou</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Formato do código</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extensão</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Falha ao abrir arquivo para escrita</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Falha ao abrir arquivo para leitura</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Tempo decorrido:</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Falha ao encontrar informações da versão,certifique-se de que &quot;%1&quot; está instalado corretamente</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Versão encontrada</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>Falha ao abrir caminho para escrita: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Falha ao extrair</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>A rede não respondeu em %1 segundos</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Falha no download,o seguinte caminho não pode ser criado: </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Iniciar o Download</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>Problema à frente, falha ao excluir pasta: %1</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>Falha ao encontrar o executável &quot;bsdtar.exe&quot;</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Falha no  download</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Falha ao analisar arquivo JSON do GitHub</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Baixando</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Atualização concluída, reinicie para usar a nova versão</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation>Canal Seguro do Windows</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Arquivo não encontrado</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Download completo</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Extraindo arquivo: </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Processamento</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Download concluído</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Redefinindo as pastas de Download para o padrão</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Pós processamento</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Forçar download</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Mostrar janela de log</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Data De Upload:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Duração:</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Nome da legenda</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Oções de download</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Opções de downloads extras</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Intervalo de tempo de Download</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Download de capítulos</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Dividido por capítulos</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Meios de comunicação já em arquivo</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Escuro</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Tempo restante</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Baixado</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>%1 já baixado</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Isso pode levar muito tempo</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Velocidade:</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>Há uma atualização para %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>A versão mais recente é %1 atualizada</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>Verificação da versão instalada de %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>Versão encontrada: %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>A versão mais recente é: %1</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Por favor,atualize &quot;%1&quot; para pelo menos a versão &quot;%2&quot;</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>Melhor áudio disponível apenas</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>Melhor áudio disponível apenas (mp3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>Melhor vídeo de áudio disponível</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>Melhor áudio com resolução de vídeo de %1</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>Aviso: pular o conteúdo da área de transferência</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>Mostre as pastas primeiro</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>Organize em ordem crescente</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>Organize por data</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>Organize pelo nome</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>Organize em ordem decrescente</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>Sem filtro</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>Outros sites</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>Extraia áudio</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>Extrair áudio como mp3</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>árabe</translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>Melhor apenas áudio disponível+miniatura</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>Youtube</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>Atualização automática desativada por %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>A versão mais recente é %1, atualização automática desativada</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>Autor: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>Como contagem: %1</translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation>Coreano (Coréia)</translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation>Faça login para confirmar que você não é um bot</translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation>Mostre/oculto controles</translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation>Ocultar lista</translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Definir arquivo em lote</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Baixando comentários</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Download</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salvar</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copirar Url</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Mostrar legendas</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Mostrar comentários</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Mostrar opções de mídia</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Baixar parte da mídia</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Definir</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Baixando legendas</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>Classificar por data ascendente</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>Classificar por data descendente</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>Classificar por curtidas</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Definir como padrão</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Selecione um arquivo de Engine</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Definir pasta de download</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Definir Padrões</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Excluir todos</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomear</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation>Tem certeza de que deseja excluir o arquivo abaixo?</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation>Tem certeza de que deseja excluir a pasta abaixo?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sim</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Não</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation>Tem certeza de que deseja excluir todos os arquivos e pastas?</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Renomear o arquivo para o texto abaixo</translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation>Renomeie a pasta para o texto abaixo</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation>Tem certeza de que deseja excluir itens selecionados?</translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Janela de log</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Abrir</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Ocultar controles</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Obter opções de lista:</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copiar Url</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Mostrar comentários</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Mostrar todas as atualizações</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Fazer Download de todas atualizações</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Gerenciar assinaturas</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Número de páginas baixadas</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Baixando informações do vídeo</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Mostrar controles</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Isso pode levar muito tempo</translation>
    </message>
</context>
</TS>
